@@ -1,5 +1,4 @@
 from .version import __version__ as __version__
-from .project import project as project
 
 from .aead import (
     AEAD as AEAD,
@@ -29,6 +28,7 @@ from .symmetric_key_ratchet import (
 from .types import (
     EncryptedMessage as EncryptedMessage,
     Header as Header,
+    JSONType as JSONType,
     JSONObject as JSONObject,
     SkippedMessageKeys as SkippedMessageKeys
 )
